@@ -83,7 +83,7 @@ void LocalFileListing::triggerRefreshOfContent()
 
     scanDirectoryTree(d->mRootPath);
 
-    Q_EMIT indexingFinished();
+    Q_EMIT indexingFinished(importedTracksCount());
 }
 
 
